#
# spec file for package procmail
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           procmail
Version:        3.24
Release:        5.1
Summary:        A program for local e-mail delivery
License:        Artistic-1.0 OR GPL-2.0-or-later
Group:          Productivity/Networking/Email/Clients
URL:            https://github.com/BuGlessRB/procmail/
Source0:        https://github.com/BuGlessRB/procmail/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        procmail-%{version}-patches.tar.bz2
Patch0:         procmail-3.22-mailstat.patch
Patch1:         procmail-3.22.dif
Patch2:         procmail-cflags.dif
Patch3:         procmail-3.22-headerconcat.dif
Patch4:         procmail-3.22-owl-truncate.dif
Patch5:         procmail-3.22-autoconf.dif
Patch6:         procmail-3.22-ipv6.patch
# PATCH-FIX-SUSE Avoid that link() follows symbolic links
Patch7:         procmail-o_nofollow.patch
# PATCH-FIX-SUSE bmwiedemann -- make build reproducible
Patch8:         reproducible.patch
Patch10:        procmail-fix-Werror=return-type.patch
Patch11:        reproducible2.patch
BuildRequires:  postfix
Requires:       /bin/sed
Recommends:     %{_bindir}/mimencode

%description
Sendmail calls procmail to deliver email into a local folder. Procmail
can be configured to store e-mail in different folders.

%prep
%setup -q -b1
for p in ../procmail-%{version}-patches/* ; do
    test -e $p || break
    echo Patch $p
    patch -s -p1 --fuzz=0 < $p
done
%patch -P 0
%patch -P 1
%patch -P 2
%patch -P 3
%patch -P 4
%patch -P 5
%patch -P 6
%patch -P 7 -b .nofollow
%patch -P 8 -p1
%patch -P 10 -p1
%patch -P 11 -p1
sed -ri '\@^/\*@,\@\*/@{ s@^(/\*[^*]*)(/\*)@\1\*/ \2@; }' config.h
sed -ri '\@^/\*@,\@\*/@{ s@^(/\*[^*]*)(/\*)@\1\*/ \2@; }' src/includes.h
sed -ri '\@^#.*[[:blank:]]+/\*[^/]*$@M,\@\*/$@{ s@(^[[:blank:]]+)/\*@\1  @;}' src/includes.h

%build
%define _lto_cflags %{nil}
    cflags ()
    {
	local flag=$1; shift
	local var=$1; shift
	local gold
	test -n "${flag}" -a -n "${var}" || return
	case "${!var}" in
	*${flag}*) return
	esac
	if type ld.gold > /dev/null 2>&1 ; then
	    gold=-Wl,-fuse-ld=gold
	fi
	case "$flag" in
	-Wl,*)
	    set -o noclobber
	    if echo 'int main () { return 0; }' | \
		${CC:-gcc} %{optflags} -Werror $gold $flag -o /dev/null -xc - > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	    set +o noclobber
	    rm -f ldtest.c
	    ;;
	*)
	    if ${CC:-gcc} -Werror $gold $flag -S -o /dev/null -xc /dev/null > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	    if ${CXX:-g++} -Werror $gold $flag -S -o /dev/null -xc++ /dev/null > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	esac
    }
    RPM_OPT_FLAGS="%{optflags}"
    XCFLAGS="$(getconf LFS_CFLAGS)"
    cflags -fPIE                    RPM_OPT_FLAGS
    cflags -std=c89                 RPM_OPT_FLAGS
    cflags -Wno-parentheses         RPM_OPT_FLAGS
    cflags -Wno-sign-compare        RPM_OPT_FLAGS
    cflags -Wno-unprototyped-calls  RPM_OPT_FLAGS
    cflags -pipe                    RPM_OPT_FLAGS
    cflags -fno-strict-aliasing     XCFLAGS
    cflags -Wl,-O2                  LDFLAGS0
    cflags -Wl,--hash-size=8599     LDFLAGS0
    cflags -pie                     LDFLAGS0
    export RPM_OPT_FLAGS XCFLAGS LDFLAGS0
    %make_build XCFLAGS="${XCFLAGS}" MANDIR=%{_mandir} LDFLAGS0="${LDFLAGS0}"

%install
    mkdir -p %{buildroot}%{_mandir}/man{1,5} %{buildroot}%{_bindir}
    make MANDIR=%{buildroot}%{_mandir} BINDIR=%{buildroot}%{_bindir} install
    install -m 644 man/mailstat.man %{buildroot}%{_mandir}/man1/mailstat.1

%files
%license COPYING
%doc Artistic
%doc FAQ FEATURES README examples
%{_bindir}/formail
%{_bindir}/lockfile
%{_bindir}/mailstat
%{_bindir}/procmail
%{_mandir}/man1/formail.1%{?ext_man}
%{_mandir}/man1/lockfile.1%{?ext_man}
%{_mandir}/man1/procmail.1%{?ext_man}
%{_mandir}/man1/mailstat.1%{?ext_man}
%{_mandir}/man5/procmailex.5%{?ext_man}
%{_mandir}/man5/procmailrc.5%{?ext_man}
%{_mandir}/man5/procmailsc.5%{?ext_man}

%changelog
* Wed Mar 19 2025 Andreas Stieger <andreas.stieger@gmx.de>
- drop unneeded build dependency on pcre
* Wed Feb 12 2025 Dr. Werner Fink <werner@suse.de>
- Add patch procmail-o_nofollow.patch
  * Avoid to follow symblic link below /var/spool/mail/
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Dec  3 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Update reproducible.patch to drop more benchmarking (boo#1041534)
* Wed Aug  9 2023 Dr. Werner Fink <werner@suse.de>
- Update to procmail 3.24 (New Upstream)
  - Don't coredump in comsat code if interrupted early
  - Correctly handle COMSAT=on
  - Once used, the 'H' and 'r' flags would never be cleared
  - Fix possible buffer overflow in variable-capture actions
  - Fix up the parsing of variable-capture actions
  - LMTP code assumed sizeof(long)==sizeof(int)
  - SHELL is now always preset to /bin/sh.  USER_SHELL contains
    the shell from the user's passwd entry
  - When HOST is mismatched, reset it for the next rcfile
  - Always read in a new, global rcfile (/etc/procmail.conf)
    to allow runtime configuration of variables like DEFAULT.
    This rcfile cannot deliver or filter messages
  - Mismatched HOST in /etc/procmailrc didn't discard the message
  - backquote expansion in a condition disabled header
    concatenation for that condition
  - LMTP didn't correctly handle quoted localparts
  - Removed SIZE extension from LMTP (unsupportable semantics)
  - Don't coredump if unable to exec /bin/sh
  - Enable "+detail" processing in LMTP mode by passing the
    delimiter (e.g., "+") as an optional argument after -z
  - In LMTP mode, save the domain of the recipient in
    PROCMAIL_DOMAIN
  - Set PROCMAIL_MODE to one of "d", "m", "z", or "" to reflect
    the mode option it was invoked with, if any
  - Fixed all bugs collected by Debian and others
    during the past 21 years.  See the git commit history
    for detailed descriptions.
- Port patches
  * procmail-3.22-autoconf.dif
  * procmail-3.22-headerconcat.dif
  * procmail-3.22-ipv6.patch
  * procmail-3.22-mailstat.patch
  * procmail-3.22-owl-truncate.dif
  * procmail-3.22.dif
  * procmail-cflags.dif
- Remove former Debian and SUSE patches from procmail-3.22-patches.tar.bz2
  * 04
  * 06
  * 10
  * 11
  * 12
  * 13
  * 14
  * 15
  * 16
  * 17
  * 18
  * 19
  * 22
  * 23
  * 24
  * 25
  * 26
  * 27
  * 28
  * 29
  * 30
- Collect and port our patches from old procmail-3.22-patches.tar.bz2
  into new procmail-3.24-patches.tar.bz2
  * 01
  * 02
  * 03
  * 05
  * 07
  * 08
  * 09
  * 20
  * 21
* Sun May  2 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Thu Nov 26 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible2.patch to negate influences from preinstallimage
  to make package build reproducible
* Fri Oct 23 2020 Dr. Werner Fink <werner@suse.de>
- Do not use lto compiler flags at all with this kind of code
* Fri Nov  8 2019 Dr. Werner Fink <werner@suse.de>
- Add latest patch sets from Debian:
  * patch set 27 replaces procmail-3.22-CVE-2014-3618.patch
  * patch set 28 does fix off-by-one error that makes procmail to
    segfault on certain .procmailrc files
  * patch set 29 does fix formail memory corruption
  * patch set 30 replaces procmail-formisc.c.patch for CVE-2017-16844
- Remove obsolate patches
  * procmail-3.22-CVE-2014-3618.patch
  * procmail-formisc.c.patch
* Fri Jul 12 2019 Martin Liška <mliska@suse.cz>
- Add procmail-fix-Werror=return-type.patch in order to fix
  - Werror=return-type errors.
* Fri Nov 17 2017 werner@suse.de
- Add patch procmail-formisc.c.patch to fix bug bsc#1068648
  CVE-2017-16844
* Mon May 29 2017 bwiedemann@suse.com
- Add reproducible.patch to have binaries independent of speed
  of compile system (boo#1041534)
* Mon Dec 29 2014 meissner@suse.com
- build with PIE
* Mon Dec 22 2014 dimstar@opensuse.org
- Drop .keyring and .sig files: procmail is signed using an MD5
  type key, which is no longer accepted by GPG 2.1
- Drop the usage of gpg-offline: we don't have keys to verify and
  the source validator performs the action transparent nowadays.
* Thu Sep  4 2014 werner@suse.de
- Correct licenses
- Add cflags() shell function to be able to check for compiler,
  linker, and assembler flags, that is if those are supported by
  the compiler, linker, or assembler.
* Thu Sep  4 2014 werner@suse.de
- Add patch procmail-3.22-CVE-2014-3618.patch to fix heap-overflow
  in procmail's formail utility when processing specially-crafted
  email headers (bnc#894999, CVE-2014-3618)
* Mon Apr 15 2013 idonmez@suse.com
- Cleanup spec file
- Add Source URL, see https://en.opensuse.org/SourceUrls
- Add GPG verification
* Thu Feb 28 2013 coolo@suse.com
- update license to new format
* Mon Nov 14 2011 werner@suse.de
- Go forward and add the patches from Debian
- Also add ipv6 patch from openmamba
- Adop or drop our own patches
- Do not sleep a second on NFS based home shares
- Support LMTP (rfc2033: Local Mail Transfer Protocol) server
* Tue Feb  8 2011 seife+obs@b1-systems.com
- the only thing that needs mimencode are the examples
  change the "Requires: mimencode" to "Recommends"
* Tue Dec 15 2009 jengelh@medozas.de
- enable parallel building
* Fri Nov 20 2009 werner@suse.de
- Fix that last fix (bnc#556509)
* Fri Jan 30 2009 od@suse.de
- assume RFC2822-compliant header continuation lines, do not cover
  up for older mail clients that insert more spacing (bnc#469222)
* Tue Nov 11 2008 kukuk@suse.de
- vacation is no required package
* Tue Mar  4 2008 werner@suse.de
- Avoid warnings due oldish C code of procmail
- Be sure that autoconf catchs missing pw_class
* Thu Jun 28 2007 werner@suse.de
- Be sure that standard programs are available in procmailrc
* Mon Jan  8 2007 werner@suse.de
- Use only fcntl(2) for locking, do not mix with flock(2) (#231845)
* Fri May 26 2006 schwab@suse.de
- Don't strip binaries.
* Thu May 11 2006 werner@suse.de
- Enable large file support (bug #174497)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 werner@suse.de
- Fix the last bug fix to re-enable biff/comsat (bug #135883)
* Mon Nov  7 2005 werner@suse.de
- Do not truncate a folder if reached quota (bug #132530)
* Sun May  9 2004 od@suse.de
- fixed handling of folded headers: delete leading whitespace
* Fri Mar 26 2004 ro@suse.de
- added postfix to neededforbuild
* Mon Feb 23 2004 werner@suse.de
- Reenabled locking with fcntl.
* Mon Feb 23 2004 werner@suse.de
- Update to procmail 3.22 (includes maildir feature)
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Mon Sep  1 2003 pthomas@suse.de
- Pass -fno-strict-aliasing to gcc, as regexp.c uses type punning
  and thus could be miscompiled.
* Wed May 28 2003 coolo@suse.de
- use BuildRoot
* Tue May 13 2003 mmj@suse.de
- Use %%defattr
* Wed Jan 22 2003 mmj@suse.de
- Enabled locking with fcntl as well
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Jan 11 2001 werner@suse.de
- Update to 3.15.1 due security:
  * A race to create the mailspool would bounce one of the
    messages due to an internal error
  * LC_ in KEEPENV would preserve only the first LC_foo variable
  * Strip runtime linker variables (LD_*) from environment on
    all platforms
  * Drop duplicate and malformed environment entries
* Tue Jan  9 2001 werner@suse.de
- Update to 3.15 due to security issue
* Thu Nov 23 2000 werner@suse.de
- Update to 3.14
* Wed Jun  7 2000 ro@suse.de
- doc relocation
* Sun Feb 27 2000 kukuk@suse.de
- Move /usr/man -> /usr/share/man
* Mon Dec  6 1999 werner@suse.de
- Fix default PATH
* Fri Oct  1 1999 werner@suse.de
- New version 3.13.1
- Add procmail-maildir.patch (supporting of maildirs with ending '/')
- Add procmail-locking.patch (no locking for directories required)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jul 17 1998 werner@suse.de
- Use mktemp
* Thu Jul 16 1998 werner@suse.de
- fix for mailstat script
* Mon Jul  7 1997 florian@suse.de
- update to version 3.11-pre7
- add docu files in /usr/doc/packages
* Thu Jan  2 1997 florian@suse.de
- Umstieg auf non-sgid-mail spool-Verzeichnis.
